/*
 *
 * Copyright  2004, University of Washington, 
 * Department of Computer Science and Engineering. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution.
 *
 * 3. Neither name of the University of Washington, Department of Computer 
 * Science and Engineering nor the names of its contributors may be used to 
 * endorse or promote products derived from this software without specific 
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR 
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 *
 */


package cse466.packets;


public class AdjustGlobalsPacket extends CSE466Packet {
  public int node0;
  public int repetition;
  public int minListen;
  public int maxListen;
  public int threshold;
  public int minThreshold;
  public int probability;
  public int silence;
  public int transmitPower;

  public AdjustGlobalsPacket() {
    node0 = 0;
    repetition = 3;
    minListen = 2000;
    maxListen = 1500;
    threshold = 600;
    minThreshold = 100;
    probability = 10;
    silence = 10;
    transmitPower = 1;
  }

  public int getProperAMType(){
    return 50;
  }

  public byte[] setFromBytes(byte[] fromArray){
    byte[] me = super.setFromBytes(fromArray);
    node0         = bytesToInt(me[ 0], me[ 1]);
    repetition    = bytesToInt(me[ 2], me[ 3]);
    minListen     = bytesToInt(me[ 4], me[ 5]);
    maxListen     = bytesToInt(me[ 6], me[ 7]);
    threshold     = bytesToInt(me[ 8], me[ 9]);
    minThreshold  = bytesToInt(me[10], me[11]);
    probability   = bytesToInt(me[12], me[13]);
    silence       = bytesToInt(me[14], me[15]);
    transmitPower = bytesToInt(me[16], me[17]);
    return subArray(me, 18);
  }

  protected byte[] getByteArray(byte[] childByteArray){
    byte[] ret = new byte[childByteArray.length + 18];
    ret[ 0] = intToLSB(node0);
    ret[ 1] = intToMSB(node0);
    ret[ 2] = intToLSB(repetition);
    ret[ 3] = intToMSB(repetition);
    ret[ 4] = intToLSB(minListen);
    ret[ 5] = intToMSB(minListen);
    ret[ 6] = intToLSB(maxListen);
    ret[ 7] = intToMSB(maxListen);
    ret[ 8] = intToLSB(threshold);
    ret[ 9] = intToMSB(threshold);
    ret[10] = intToLSB(minThreshold);
    ret[11] = intToMSB(minThreshold);
    ret[12] = intToLSB(probability);
    ret[13] = intToMSB(probability);
    ret[14] = intToLSB(silence);
    ret[15] = intToMSB(silence);
    ret[16] = intToLSB(transmitPower);
    ret[17] = intToMSB(transmitPower);
    copyIntoArray(ret, childByteArray, 18);
    return super.getByteArray(ret);
  }

  public byte[] getByteArray(){
    return getByteArray(new byte[0]);
  }

  public void print(){
    super.print();
    System.out.println("AG     node0               : " + Integer.toHexString(node0));
    System.out.println("AG     repetition          : " + Integer.toHexString(repetition));
    System.out.println("AG     minListen           : " + Integer.toHexString(minListen));
    System.out.println("AG     maxListen           : " + Integer.toHexString(maxListen));
    System.out.println("AG     threshold           : " + Integer.toHexString(threshold));
    System.out.println("AG     minThreshold        : " + Integer.toHexString(minThreshold));
    System.out.println("AG     probability         : " + Integer.toHexString(probability));
    System.out.println("AG     silence             : " + Integer.toHexString(silence));
    System.out.println("AG     transmitPower       : " + Integer.toHexString(transmitPower));
  }

  public boolean equals(AdjustGlobalsPacket other) {
    if(node0         != other.node0        ) return false;    
    if(repetition    != other.repetition   ) return false;    
    if(minListen     != other.minListen    ) return false;    
    if(maxListen     != other.maxListen    ) return false;    
    if(threshold     != other.threshold    ) return false;    
    if(minThreshold  != other.minThreshold ) return false;    
    if(probability   != other.probability  ) return false;    
    if(silence       != other.silence      ) return false;    
    if(transmitPower != other.transmitPower) return false;
    return super.equals(other);
  }
}

